from setuptools import setup

setup(name='uplo',
      version='1.0',
      description='Python Project',
      author='sneha',
      author_email='sneha@gmail.com',
      url='https://pypi.org/manage/projects/',
      packages=['test_code'],
     )